﻿using Microsoft.VisualStudio.TestTools.UnitTesting;
using OrdersApp;
using Sid.Utilities;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace OrdersApp.Tests
{
	[TestClass()]
	public class CmdLineTests
	{
		[TestMethod()]
		public void GetFlagValueTest()
		{
			CmdLine cmd = new CmdLine(new string[] { "-port", "80", "-protocol", "http", "start" });
			Assert.AreEqual("80", cmd.GetFlagValue("port"));
			Assert.AreEqual("http", cmd.GetFlagValue("protocol"));
		}

		[TestMethod()]
		public void IsFlagPresentTest()
		{
			CmdLine cmd = new CmdLine(new string[] { "-port", "80", "-protocol", "http", "start", "-nologging" });
			Assert.AreEqual<bool>(cmd.IsFlagPresent("nologging"), true);
			Assert.AreEqual<bool>(cmd.IsFlagPresent("port"), true);
			Assert.AreEqual<bool>(cmd.IsFlagPresent("doesnotexist"), false);
		}

		[TestMethod()]
		public void GetPositionalArgumentTest()
		{
			CmdLine cmd = new CmdLine(new string[] { "-port", "80", "-protocol", "http", "start", "-nologging" });
			Assert.AreEqual<string>(cmd.GetPositionalArgument(0), "start");
		}
		
		[TestMethod()]
		public void FlagCountTest()
		{
			CmdLine cmd = new CmdLine(new string[] { "-port", "80", "-protocol", "http", "start", "-nologging" });
			Assert.AreEqual<int>(cmd.FlagCount, 3);

			cmd = new CmdLine(null);
			Assert.AreEqual<int>(cmd.FlagCount, 0);

			cmd = new CmdLine(new string[] { "-port" });
			Assert.AreEqual<int>(cmd.FlagCount, 1);
		}

		[TestMethod()]
		public void RawArgCountTest()
		{
			CmdLine cmd = new CmdLine(new string[] { "-port", "80", "-protocol", "http", "start", "-nologging" });
			Assert.AreEqual<int>(cmd.RawArgCount, 6);

			cmd = new CmdLine(null);
			Assert.AreEqual<int>(cmd.RawArgCount, 0);

			cmd = new CmdLine(new string[] { "-port" });
			Assert.AreEqual<int>(cmd.RawArgCount, 1);
		}

		[TestMethod()]
		public void PositionalArgCountTest()
		{
			CmdLine cmd = new CmdLine(new string[] { "-port", "80", "-protocol", "http", "start", "-nologging" });
			Assert.AreEqual<int>(cmd.PositionalArgumentCount, 1);

			cmd = new CmdLine(null);
			Assert.AreEqual<int>(cmd.PositionalArgumentCount, 0);

			cmd = new CmdLine(new string[] { "-port" });
			Assert.AreEqual<int>(cmd.PositionalArgumentCount, 0);
		}
	}
}